import { Component } from "@angular/core";
import { Router } from "@angular/router";
import { UserLoginService } from "../../services/user-login.service";
var LoginComponent = (function () {
    function LoginComponent(router, userService) {
        this.router = router;
        this.userService = userService;
        this.mfaStep = false;
        this.mfaData = {
            destination: '',
            callback: null
        };
        console.log("LoginComponent constructor");
    }
    LoginComponent.prototype.ngOnInit = function () {
        this.errorMessage = null;
        console.log("Checking if the user is already authenticated. If so, then redirect to the secure site");
        this.userService.isAuthenticated(this);
    };
    LoginComponent.prototype.onLogin = function () {
        if (this.email == null || this.password == null) {
            this.errorMessage = "All fields are required";
            return;
        }
        this.errorMessage = null;
        this.userService.authenticate(this.email, this.password, this);
    };
    LoginComponent.prototype.cognitoCallback = function (message, result) {
        if (message != null) {
            //error
            this.errorMessage = message;
            console.log("result: " + this.errorMessage);
            if (this.errorMessage === 'User is not confirmed.') {
                console.log("redirecting");
                this.router.navigate(['/home/confirmRegistration', this.email]);
            }
            else if (this.errorMessage === 'User needs to set password.') {
                console.log("redirecting to set new password");
                this.router.navigate(['/home/newPassword']);
            }
        }
        else {
            //success
            this.router.navigate(['/securehome']);
        }
    };
    LoginComponent.prototype.handleMFAStep = function (challengeName, challengeParameters, callback) {
        var _this = this;
        this.mfaStep = true;
        this.mfaData.destination = challengeParameters.CODE_DELIVERY_DESTINATION;
        this.mfaData.callback = function (code) {
            if (code == null || code.length === 0) {
                _this.errorMessage = "Code is required";
                return;
            }
            _this.errorMessage = null;
            callback(code);
        };
    };
    LoginComponent.prototype.isLoggedIn = function (message, isLoggedIn) {
        if (isLoggedIn) {
            this.router.navigate(['/securehome']);
        }
    };
    LoginComponent.prototype.cancelMFA = function () {
        this.mfaStep = false;
        return false; //necessary to prevent href navigation
    };
    LoginComponent.decorators = [
        { type: Component, args: [{
                    selector: 'awscognito-angular2-app',
                    templateUrl: './login.component.html',
                    styleUrls: ['./login.component.css']
                },] },
    ];
    /** @nocollapse */
    LoginComponent.ctorParameters = function () { return [
        { type: Router, },
        { type: UserLoginService, },
    ]; };
    return LoginComponent;
}());
export { LoginComponent };
//# sourceMappingURL=login.component.js.map