import { Inject, Injectable } from "@angular/core";
import { CognitoUtil } from "./cognito.service";
import { AuthenticationDetails, CognitoUser, CognitoUserAttribute } from "amazon-cognito-identity-js";
import * as AWS from "aws-sdk/global";
var UserRegistrationService = (function () {
    function UserRegistrationService(cognitoUtil) {
        this.cognitoUtil = cognitoUtil;
    }
    UserRegistrationService.prototype.register = function (user, callback) {
        console.log("UserRegistrationService: user is " + user);
        var attributeList = [];
        var dataEmail = {
            Name: 'email',
            Value: user.email
        };
        attributeList.push(new CognitoUserAttribute(dataEmail));
        attributeList.push(new CognitoUserAttribute({
            Name: 'phone_number',
            Value: user.phone_number
        }));
        attributeList.push(new CognitoUserAttribute({
            Name: 'gender',
            Value: user.gender
        }));
        attributeList.push(new CognitoUserAttribute({
            Name: 'family_name',
            Value: user.family_name
        }));
        attributeList.push(new CognitoUserAttribute({
            Name: 'given_name',
            Value: user.given_name
        }));
        attributeList.push(new CognitoUserAttribute({
            Name: 'birthdate',
            Value: user.birth_date
        }));
        attributeList.push(new CognitoUserAttribute({
            Name: 'gender',
            Value: user.gender
        }));
        this.cognitoUtil.getUserPool().signUp(user.name, user.password, attributeList, null, function (err, result) {
            if (err) {
                callback.cognitoCallback(err.message, null);
            }
            else {
                console.log("UserRegistrationService: registered user is " + result);
                callback.cognitoCallback(null, result);
            }
        });
    };
    UserRegistrationService.prototype.confirmRegistration = function (username, confirmationCode, callback) {
        var userData = {
            Username: username,
            Pool: this.cognitoUtil.getUserPool()
        };
        var cognitoUser = new CognitoUser(userData);
        cognitoUser.confirmRegistration(confirmationCode, true, function (err, result) {
            if (err) {
                callback.cognitoCallback(err.message, null);
            }
            else {
                callback.cognitoCallback(null, result);
            }
        });
    };
    UserRegistrationService.prototype.resendCode = function (username, callback) {
        var userData = {
            Username: username,
            Pool: this.cognitoUtil.getUserPool()
        };
        var cognitoUser = new CognitoUser(userData);
        cognitoUser.resendConfirmationCode(function (err, result) {
            if (err) {
                callback.cognitoCallback(err.message, null);
            }
            else {
                callback.cognitoCallback(null, result);
            }
        });
    };
    UserRegistrationService.prototype.newPassword = function (newPasswordUser, callback) {
        console.log(newPasswordUser);
        // Get these details and call
        //cognitoUser.completeNewPasswordChallenge(newPassword, userAttributes, this);
        var authenticationData = {
            Username: newPasswordUser.username,
            Password: newPasswordUser.existingPassword,
        };
        var authenticationDetails = new AuthenticationDetails(authenticationData);
        var userData = {
            Username: newPasswordUser.username,
            Pool: this.cognitoUtil.getUserPool()
        };
        console.log("UserLoginService: Params set...Authenticating the user");
        var cognitoUser = new CognitoUser(userData);
        console.log("UserLoginService: config is " + AWS.config);
        cognitoUser.authenticateUser(authenticationDetails, {
            newPasswordRequired: function (userAttributes, requiredAttributes) {
                // User was signed up by an admin and must provide new
                // password and required attributes, if any, to complete
                // authentication.
                // the api doesn't accept this field back
                delete userAttributes.email_verified;
                cognitoUser.completeNewPasswordChallenge(newPasswordUser.password, requiredAttributes, {
                    onSuccess: function (result) {
                        callback.cognitoCallback(null, userAttributes);
                    },
                    onFailure: function (err) {
                        callback.cognitoCallback(err, null);
                    }
                });
            },
            onSuccess: function (result) {
                callback.cognitoCallback(null, result);
            },
            onFailure: function (err) {
                callback.cognitoCallback(err, null);
            }
        });
    };
    UserRegistrationService.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    UserRegistrationService.ctorParameters = function () { return [
        { type: CognitoUtil, decorators: [{ type: Inject, args: [CognitoUtil,] },] },
    ]; };
    return UserRegistrationService;
}());
export { UserRegistrationService };
//# sourceMappingURL=user-registration.service.js.map